.highlight pre .hll { background-color: #2f2f2f }
.highlight pre, .highlighttable pre { background: #3f3f3f; color: #dcdccc }
.highlight pre .c { color: #7f9f7f } /* Comment */
.highlight pre .err { color: #e37170; background-color: #3d3535 } /* Error */
.highlight pre .g { color: #dcdccc } /* Generic */
.highlight pre .k { color: #f0dfaf; font-weight: bold } /* Keyword */
.highlight pre .l { color: #dcdccc } /* Literal */
.highlight pre .n { color: #dcdccc } /* Name */
.highlight pre .o { color: #dcdccc } /* Operator */
.highlight pre .x { color: #dcdccc } /* Other */
.highlight pre .p { color: #dcdccc } /* Punctuation */
.highlight pre .cm { color: #6CA0A3 } /* Comment.Multiline */
.highlight pre .cp { color: #94bff3 } /* Comment.Preproc */
.highlight pre .c1 { color: #7f9f7f } /* Comment.Single */
.highlight pre .cs { color: #7f9f7f } /* Comment.Special */
.highlight pre .gd { color: #dcdccc } /* Generic.Deleted */
.highlight pre .ge { color: #dcdccc } /* Generic.Emph */
.highlight pre .gr { color: #dcdccc } /* Generic.Error */
.highlight pre .gh { color: #dcdccc } /* Generic.Heading */
.highlight pre .gi { color: #dcdccc } /* Generic.Inserted */
.highlight pre .go { color: #dcdccc } /* Generic.Output */
.highlight pre .gp { color: #dcdccc } /* Generic.Prompt */
.highlight pre .gs { color: #dcdccc } /* Generic.Strong */
.highlight pre .gu { color: #dcdccc } /* Generic.Subheading */
.highlight pre .gt { color: #dcdccc } /* Generic.Traceback */
.highlight pre .kc { color: #bfebbf } /* Keyword.Constant */
.highlight pre .kd { color: #f0dfaf; font-weight: bold } /* Keyword.Declaration */
.highlight pre .kn { color: #f0dfaf; font-weight: bold } /* Keyword.Namespace */
.highlight pre .kp { color: #dcdccc; font-weight: bold } /* Keyword.Pseudo */
.highlight pre .kr { color: #dcdccc; font-weight: bold } /* Keyword.Reserved */
.highlight pre .kt { color: #7cb8bb } /* Keyword.Type */
.highlight pre .ld { color: #dcdccc } /* Literal.Date */
.highlight pre .m { color: #8cd0d3 } /* Literal.Number */
.highlight pre .s { color: #cc9393 } /* Literal.String */
.highlight pre .na { color: #dcdccc } /* Name.Attribute */
.highlight pre .nb { color: #93e0e3 } /* Name.Builtin */
.highlight pre .nc { color: #7cb8bb } /* Name.Class */
.highlight pre .no { color: #dcdccc } /* Name.Constant */
.highlight pre .nd { color: #efef8f } /* Name.Decorator */
.highlight pre .ni { color: #dcdccc } /* Name.Entity */
.highlight pre .ne { color: #ebed9f; font-weight: bold } /* Name.Exception */
.highlight pre .nf { color: #8cd0d3 } /* Name.Function */
.highlight pre .nl { color: #f0dfaf } /* Name.Label */
.highlight pre .nn { color: #dcdccc } /* Name.Namespace */
.highlight pre .nx { color: #dcdccc } /* Name.Other */
.highlight pre .py { color: #dcdccc } /* Name.Property */
.highlight pre .nt { color: #dcdccc } /* Name.Tag */
.highlight pre .nv { color: #dfaf8f } /* Name.Variable */
.highlight pre .ow { color: #f0dfaf; font-weight: bold } /* Operator.Word */
.highlight pre .w { color: #dcdccc } /* Text.Whitespace */
.highlight pre .mf { color: #dcdccc } /* Literal.Number.Float */
.highlight pre .mh { color: #dcdccc } /* Literal.Number.Hex */
.highlight pre .mi { color: #dcdccc } /* Literal.Number.Integer */
.highlight pre .mo { color: #dcdccc } /* Literal.Number.Oct */
.highlight pre .sb { color: #cc9393 } /* Literal.String.Backtick */
.highlight pre .sc { color: #cc9393 } /* Literal.String.Char */
.highlight pre .sd { color: #cc9393 } /* Literal.String.Doc */
.highlight pre .s2 { color: #cc9393 } /* Literal.String.Double */
.highlight pre .se { color: #cc9393 } /* Literal.String.Escape */
.highlight pre .sh { color: #cc9393 } /* Literal.String.Heredoc */
.highlight pre .si { color: #cc9393 } /* Literal.String.Interpol */
.highlight pre .sx { color: #cc9393 } /* Literal.String.Other */
.highlight pre .sr { color: #cc9393 } /* Literal.String.Regex */
.highlight pre .s1 { color: #cc9393 } /* Literal.String.Single */
.highlight pre .ss { color: #cc9393 } /* Literal.String.Symbol */
.highlight pre .bp { color: #f0dfaf; font-weight: bold } /* Name.Builtin.Pseudo */
.highlight pre .vc { color: #efef8f } /* Name.Variable.Class */
.highlight pre .vg { color: #dcdccc } /* Name.Variable.Global */
.highlight pre .vi { color: #dcdccc } /* Name.Variable.Instance */
.highlight pre .il { color: #8cd0d3 } /* Literal.Number.Integer.Long */
