<footer class="post-info">
    <span class="label label-default">Published</span>
    <span class="published">
        <i class="fa fa-calendar"></i><time datetime="{{ article.date.isoformat() }}"> {{ article.date | article_date }}</time>
    </span>
    {# Uncomment if you want the author shown #}
    {#{% if article.author %}#}
    {#<span class="label">By</span>#}
    {#<a href="{{ SITEURL }}/{{ article.author.url }}"><i class="fa fa-user"></i> {{ article.author }}</a>#}
    {#{% endif -%}-#}

    {%- if article.readtime_minutes -%}
        <span class="label label-default">Reading Time</span>
        <i class="fa fa-clock-o"></i> ~{{ article.readtime_minutes }} min
    {%- elif article.stats -%}
        <span class="label label-default">Reading Time</span>
        <i class="fa fa-clock-o"></i> ~{{ article.stats['read_mins'] }} min
    {%- endif -%}

    {#- Uncomment if you want to show Categories#}
    {#<span class="label label-default">Category</span>#}
    {#<a href="{{ SITEURL }}/{{ article.category.url }}">{{ article.category }}</a>-#}

    {%- if PDF_PROCESSOR %}
        <span class="label label-default">
            <a href="{{ SITEURL }}/pdf/{{ article.slug }}.pdf">PDF</a>
        </span>
    {% endif -%}

    {%- include 'includes/taglist.html' %}
    {% import 'includes/translations.html' as translations with context %}
    {{ translations.translations_for(article) }}
</footer><!-- /.post-info -->
