{% extends "base.html" %}

{% block title %}Error 404 - {{ SITENAME }}{%endblock%}}

{% block content %}
	<section id="content">
	    <h1 class="post-title">
	        Error 404
	    </h1>
	    <section class="post-content">Content not found. Return to <a href="{{ SITEURL }}">home</a>?</section>
	</section>
{% endblock %}
