{% assets filters="jspacker", output="js/all-js.js", "js/jquery.min.js", "js/bootstrap.min.js", "js/respond.min.js" %}
<script src="{{ SITEURL }}/{{ ASSET_URL }}" type="text/javascript"></script>
{% endassets %}
