// Typogrify
// -------------------------
//

//	Copied from typogrify.css included with pelican-bootstrap3 theme

.caps {
	font-size: 0.92em;
}
.amp {
	color: @color-amp;
	font-size: 1.05em;
	font-family: @font-family-amp;
	// font-style: italic;
	
	h1, h2, h3, h4, h5, h6,
	.h1, .h2, .h3, .h4, .h5, .h6 {
		color: @color-amp-headings;
	}
	
	.narbar-inverse,
	.list-group,
	.list-group-item,
	.panel,
	.well,
	.breadcrumb {
		color: @color-amp-inverse;
	}
	
	code,
	kbd,
	pre	{
		color: inherit;
	}
	
	
}    
.dquo {
	margin-left: -0.38em;
}
